==> labpc-0.2.tar.gz: labpc/demo/setcounter.c <==
#include <stdio.h>
#include <stdlib.h>

#include <sys/types.h>
#include <fcntl.h>
#include <unistd.h>
#include <sys/ioctl.h>

#include "labpc.h"

void Usage( void )
{
	fprintf( stderr, "Usage: setcounter [-mode terminal/oneshot/rate/squarewave/softstrobe/hardstrobe] filename count\n" );
}

int main( int argc, char **argv )
{
	unsigned short	count;
	char	*filename;
	int	mode = -1;
	int	fd;

	while (*++argv && **argv == '-') {
		if (!strcmp( *argv, "-mode" )) {
			if (!strcmp( *++argv, "terminal" )) {
				mode = MODE_TERMINAL_COUNT;
			} else if (!strcmp( *argv, "oneshot" )) {
				mode = MODE_ONE_SHOT;
			} else if (!strcmp( *argv, "rate" )) {
				mode = MODE_RATE_GENERATOR;
			} else if (!strcmp( *argv, "squarewave" )) {
				mode = MODE_SQUARE_WAVE;
			} else if (!strcmp( *argv, "softstrobe" )) {
				mode = MODE_SOFT_STROBE;
			} else if (!strcmp( *argv, "hardstrobe" )) {
				mode = MODE_HARD_STROBE;
			} else {
				fprintf( stderr, "Unknown mode: %s\n", *argv );
				Usage();
				exit( 2 );
			}
		} else {
			fprintf( stderr, "Unknown option: %s\n", *argv );
			Usage();
			exit( 2 );
		}
	}

	if ((filename = *argv) == NULL) {
		Usage();
		exit( 1 );
	}
	if (*++argv == NULL) {
		Usage();
		exit( 2 );
	}
	count = atoi( *argv );
	
	/* Open the device file for the counter */
	if ((fd = open( filename, O_WRONLY )) < 0) {
		perror( filename );
		exit( 2 );
	}

	/* Set the mode for the counter (if user has selected a mode) */
	if (mode >= 0 && ioctl( fd, COUNTER_SETMODE, mode ) < 0) {
		perror( filename );
		exit( 2 );
	}

	/* Write the value to the counter */
	if (write( fd, &count, sizeof( short ) ) < sizeof( short )) {
		perror( filename );
		exit( 2 );
	}

	close( fd );

	return 0;
}

==> labpc-0.5.tar.gz: labpc/demo/setcounter.c <==
#include <stdio.h>
#include <stdlib.h>

#include <sys/types.h>
#include <fcntl.h>
#include <unistd.h>
#include <sys/ioctl.h>

#include "labpc.h"

void Usage( void )
{
	fprintf( stderr, "Usage: setcounter [-mode terminal/oneshot/rate/squarewave/softstrobe/hardstrobe] filename count\n" );
}

int main( int argc, char **argv )
{
	unsigned short	count;
	char	*filename;
	int	mode = -1;
	int	fd;

	while (*++argv && **argv == '-') {
		if (!strcmp( *argv, "-mode" )) {
			if (!strcmp( *++argv, "terminal" )) {
				mode = MODE_TERMINAL_COUNT;
			} else if (!strcmp( *argv, "oneshot" )) {
				mode = MODE_ONE_SHOT;
			} else if (!strcmp( *argv, "rate" )) {
				mode = MODE_RATE_GENERATOR;
			} else if (!strcmp( *argv, "squarewave" )) {
				mode = MODE_SQUARE_WAVE;
			} else if (!strcmp( *argv, "softstrobe" )) {
				mode = MODE_SOFT_STROBE;
			} else if (!strcmp( *argv, "hardstrobe" )) {
				mode = MODE_HARD_STROBE;
			} else {
				fprintf( stderr, "Unknown mode: %s\n", *argv );
				Usage();
				exit( 2 );
			}
		} else {
			fprintf( stderr, "Unknown option: %s\n", *argv );
			Usage();
			exit( 2 );
		}
	}

	if ((filename = *argv) == NULL) {
		Usage();
		exit( 1 );
	}
	if (*++argv == NULL) {
		Usage();
		exit( 2 );
	}
	count = atoi( *argv );
	
	/* Open the device file for the counter */
	if ((fd = open( filename, O_WRONLY )) < 0) {
		perror( filename );
		exit( 2 );
	}

	/* Set the mode for the counter (if user has selected a mode) */
	if (mode >= 0 && ioctl( fd, COUNTER_SET_MODE, mode ) < 0) {
		perror( filename );
		exit( 2 );
	}

	/* Write the value to the counter */
	if (write( fd, &count, sizeof( short ) ) < sizeof( short )) {
		perror( filename );
		exit( 2 );
	}

	close( fd );

	return 0;
}
